@@ -6,11 +6,11 @@ from rest_framework import routers
 
 from .schema import SchemaView
 from .views import NotificationView
-from .viewsets import GroupViewSet
-
-router = routers.DefaultRouter()
-router.register("groups", GroupViewSet)
+from .viewsets import HobbyViewSet, PersonViewSet
 
+router = routers.DefaultRouter(trailing_slash=False)
+router.register("persons", PersonViewSet)
+router.register("hobbies", HobbyViewSet)
 
 urlpatterns = [
     path("admin/", admin.site.urls),
@@ -30,9 +30,9 @@ urlpatterns = [
                     name="schema-redoc",
                 ),
             ]
-            + router.urls
         ),
     ),
+    path("api/", include(router.urls)),
     path("api/", include("vng_api_common.api.urls")),
     path("ref/", include("vng_api_common.urls")),
     # this is a hack to get the parameter to show up in the API spec
