@@ -1,7 +1,5 @@
 from django.apps import AppConfig
 from django.db import models
-from django.forms.fields import CharField
-from django.utils.translation import gettext_lazy as _
 
 from drf_yasg import openapi
 from drf_yasg.inspectors.field import (
@@ -12,7 +10,7 @@ from drf_yasg.inspectors.field import (
 from rest_framework import serializers
 
 from . import fields
-from .serializers import DurationField, LengthHyperlinkedRelatedField
+from .serializers import DurationField
 
 try:
     from relativedeltafield import RelativeDeltaField
@@ -30,11 +28,10 @@ class ZDSSchemaConfig(AppConfig):
 
     def ready(self):
         from . import checks  # noqa
+        from .caching import signals  # noqa
 
         patch_duration_type()
         register_serializer_field()
-        set_custom_hyperlinkedmodelserializer_field()
-        set_charfield_error_messages()
 
 
 def patch_duration_type():
@@ -62,27 +59,3 @@ def register_serializer_field():
 
     if RelativeDeltaField is not None:
         mapping[RelativeDeltaField] = DurationField
-
-
-def set_custom_hyperlinkedmodelserializer_field():
-    """
-    Monkey-patches Django Rest Framework to avoid having to set the
-    `serializer_related_field` manually for all the base classes in the code
-    """
-    serializers.HyperlinkedModelSerializer.serializer_related_field = (
-        LengthHyperlinkedRelatedField
-    )
-
-
-def set_charfield_error_messages():
-    """
-    Monkey-patches Django forms CharField to supply error messages for min and
-    max_length. If these are not specified, the serialized validation errors
-    would be empty
-    """
-    CharField.default_error_messages.update(
-        {
-            "max_length": _("The value has too many characters"),
-            "min_length": _("The value has too few characters"),
-        }
-    )
