@@ -2,7 +2,6 @@ __all__ = [
     "API_VERSION",
     "BASE_REST_FRAMEWORK",
     "BASE_SWAGGER_SETTINGS",
-    "COMMON_SPEC",
     "LINK_FETCHER",
     "ZDS_CLIENT_CLASS",
     "GEMMA_URL_TEMPLATE",
@@ -12,7 +11,6 @@ __all__ = [
     "REDOC_SETTINGS",
     "NOTIFICATIONS_KANAAL",
     "NOTIFICATIONS_DISABLED",
-    "JWT_LEEWAY",
 ]
 
 API_VERSION = "1.0.0-rc1"  # semantic version
@@ -29,6 +27,9 @@ BASE_REST_FRAMEWORK = {
         # 'rest_framework.authentication.SessionAuthentication',
         # 'rest_framework.authentication.BasicAuthentication'
     ),
+    # there is no authentication of 'end-users', only authorization (via JWT)
+    # of applications
+    "DEFAULT_AUTHENTICATION_CLASSES": (),
     # 'DEFAULT_PERMISSION_CLASSES': (
     #     'oauth2_provider.contrib.rest_framework.TokenHasReadWriteScope',
     #     # 'rest_framework.permissions.IsAuthenticated',
@@ -59,22 +60,7 @@ BASE_REST_FRAMEWORK = {
 }
 
 BASE_SWAGGER_SETTINGS = {
-    # 'SECURITY_DEFINITIONS': {
-    #     'OAuth2': {
-    #         'type': 'oauth2',
-    #         'flow': 'application',
-    #         'tokenUrl': '/oauth2/token/',
-    #         'scopes': {
-    #             'write': 'Schrijftoegang tot de catalogus en gerelateerde objecten.',
-    #             'read': 'Leestoegang tot de catalogus en gerelateerde objecten.'
-    #         }
-    #     },
-    #     'Bearer': {
-    #         'type': 'apiKey',
-    #         'name': 'Authorization',
-    #         'in': 'header'
-    #     },
-    # },
+    "DEFAULT_GENERATOR_CLASS": "vng_api_common.generators.OpenAPISchemaGenerator",
     "DEFAULT_AUTO_SCHEMA_CLASS": "vng_api_common.inspectors.view.AutoSchema",
     "DEFAULT_INFO": "must.be.overridden",
     "DEFAULT_FIELD_INSPECTORS": (
@@ -82,6 +68,7 @@ BASE_SWAGGER_SETTINGS = {
         # 'vng_api_common.inspectors.geojson.GeometryFieldInspector',
         "vng_api_common.inspectors.fields.HyperlinkedIdentityFieldInspector",
         "vng_api_common.inspectors.fields.ReadOnlyFieldInspector",
+        "vng_api_common.inspectors.fields.JSONFieldInspector",
         "vng_api_common.inspectors.polymorphic.PolymorphicSerializerInspector",
         "vng_api_common.inspectors.fields.GegevensGroepInspector",
         "drf_yasg.inspectors.CamelCaseJSONFilter",
@@ -90,10 +77,8 @@ BASE_SWAGGER_SETTINGS = {
         "drf_yasg.inspectors.ChoiceFieldInspector",
         "drf_yasg.inspectors.FileFieldInspector",
         "drf_yasg.inspectors.DictFieldInspector",
-        "drf_yasg.inspectors.JSONFieldInspector",
         "drf_yasg.inspectors.HiddenFieldInspector",
         "drf_yasg.inspectors.RelatedFieldInspector",
-        "drf_yasg.inspectors.SerializerMethodFieldInspector",
         "drf_yasg.inspectors.SimpleFieldInspector",
         "drf_yasg.inspectors.StringDefaultFieldInspector",
     ),
@@ -116,9 +101,3 @@ GEMMA_URL_INFORMATIEMODEL_VERSIE = "2.0"
 
 NOTIFICATIONS_KANAAL = None
 NOTIFICATIONS_DISABLED = False
-
-vng_repo = "VNG-Realisatie/vng-api-common"
-vng_branch = "ref-responses"
-COMMON_SPEC = f"https://raw.githubusercontent.com/{vng_repo}/feature/{vng_branch}/vng_api_common/schemas/common.yaml"
-
-JWT_LEEWAY = 0  # default in PyJWT
