@@ -1,4 +1,6 @@
-from django.utils.translation import gettext_lazy as _
+import warnings
+
+from django.utils.translation import ugettext_lazy as _
 
 from djchoices import ChoiceItem, DjangoChoices
 
@@ -9,8 +11,10 @@ VERSION_HEADER = "API-version"
 
 SCOPE_NOTIFICATIES_PUBLICEREN_LABEL = "notificaties.scopes.publiceren"
 
+# see https://docs.nlx.io/further-reading/transaction-logs/
+HEADER_APPLICATION = "X-NLX-Request-Application-Id"
+HEADER_USER_ID = "X-NLX-Request-User-Id"
 HEADER_AUDIT = "X-Audit-Toelichting"
-HEADER_LOGRECORD_ID = "X-NLX-Logrecord-ID"
 
 FILTER_URL_DID_NOT_RESOLVE = "NO_MATCHING_OBJECT"
 
@@ -79,9 +83,27 @@ class RolTypes(DjangoChoices):
     medewerker = ChoiceItem("medewerker", "Medewerker")
 
 
+BESLUIT_CONST = "besluit"
+BESLUIT_CHOICE = ChoiceItem(BESLUIT_CONST, _("Besluit"))
+
+ZAAK_CONST = "zaak"
+ZAAK_CHOICE = ChoiceItem(ZAAK_CONST, _("Zaak"))
+
+VERZOEK_CONST = "verzoek"
+VERZOEK_CHOICE = ChoiceItem(VERZOEK_CONST, _("Verzoek"))
+
+
 class ObjectTypes(DjangoChoices):
-    besluit = ChoiceItem("besluit", _("Besluit"))
-    zaak = ChoiceItem("zaak", _("Zaak"))
+    besluit = BESLUIT_CHOICE
+    zaak = ZAAK_CHOICE
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "The use of ObjectTypes is deprecated. Create your own "
+            "enumeration based on the relevant objects you need to support.",
+            DeprecationWarning,
+        )
+        super().__init__(*args, **kwargs)
 
 
 class Archiefnominatie(DjangoChoices):
@@ -267,12 +289,13 @@ class ZaakobjectTypes(DjangoChoices):
 
 
 class ComponentTypes(DjangoChoices):
-    ac = ChoiceItem("ac", "Autorisaties API")
-    nrc = ChoiceItem("nrc", "Notificaties API")
-    zrc = ChoiceItem("zrc", "Zaken API")
-    ztc = ChoiceItem("ztc", "Catalogi API")
-    drc = ChoiceItem("drc", "Documenten API")
-    brc = ChoiceItem("brc", "Besluiten API")
+    ac = ChoiceItem("ac", "Autorisatiecomponent")
+    nrc = ChoiceItem("nrc", "Notificatierouteringcomponent")
+    zrc = ChoiceItem("zrc", "Zaakregistratiecomponent")
+    ztc = ChoiceItem("ztc", "Zaaktypecatalogus")
+    drc = ChoiceItem("drc", "Documentregistratiecomponent")
+    brc = ChoiceItem("brc", "Besluitregistratiecomponent")
+    kic = ChoiceItem("kic", "Klantinteractiescomponent")
 
 
 class CommonResourceAction(DjangoChoices):
