@@ -1,27 +1,24 @@
 import inspect
 import logging
 from collections import OrderedDict
-from itertools import chain
-from typing import Union
+from typing import Optional, Tuple
 
 from django.apps import apps
 from django.conf import settings
-from django.utils.translation import gettext, gettext_lazy as _
+from django.utils.translation import ugettext, ugettext_lazy as _
 
 from drf_yasg import openapi
 from drf_yasg.inspectors import SwaggerAutoSchema
+from drf_yasg.utils import get_consumes
 from rest_framework import exceptions, serializers, status, viewsets
 
-from ..constants import HEADER_AUDIT, HEADER_LOGRECORD_ID, VERSION_HEADER
+from ..constants import HEADER_APPLICATION, HEADER_AUDIT, HEADER_USER_ID, VERSION_HEADER
 from ..exceptions import Conflict, Gone, PreconditionFailed
 from ..geo import GeoMixin
 from ..permissions import BaseAuthRequired, get_required_scopes
 from ..search import is_search_view
-from ..serializers import (
-    FoutSerializer,
-    ValidatieFoutSerializer,
-    add_choice_values_help_text,
-)
+from ..serializers import FoutSerializer, ValidatieFoutSerializer
+from .cache import CACHE_REQUEST_HEADERS, get_cache_headers, has_cache_header
 
 logger = logging.getLogger(__name__)
 
@@ -113,20 +110,25 @@ AUDIT_TRAIL_ENABLED = apps.is_installed("vng_api_common.audittrails")
 
 AUDIT_REQUEST_HEADERS = [
     openapi.Parameter(
-        name=HEADER_LOGRECORD_ID,
+        name=HEADER_APPLICATION,
         type=openapi.TYPE_STRING,
         in_=openapi.IN_HEADER,
         required=False,
-        description=gettext(
-            "Identifier of the request, traceable throughout the network"
-        ),
+        description=ugettext("Application that performs request"),
+    ),
+    openapi.Parameter(
+        name=HEADER_USER_ID,
+        type=openapi.TYPE_STRING,
+        in_=openapi.IN_HEADER,
+        required=False,
+        description=ugettext("Identifier of the user that performs request"),
     ),
     openapi.Parameter(
         name=HEADER_AUDIT,
         type=openapi.TYPE_STRING,
         in_=openapi.IN_HEADER,
         required=False,
-        description=gettext("Explanation why the request is done"),
+        description=ugettext("Explanation why the request is done"),
     ),
 ]
 
@@ -182,23 +184,9 @@ def _view_supports_audittrail(view: viewsets.ViewSet) -> bool:
     return action_in_audit_bases
 
 
-class ResponseRef(openapi._Ref):
-    def __init__(self, resolver, response_name, ignore_unresolved=False):
-        """
-        Adds a reference to a named Response defined in the ``#/responses/`` object.
-        """
-        assert "responses" in resolver.scopes
-        super().__init__(
-            resolver, response_name, "responses", openapi.Response, ignore_unresolved
-        )
-
-
 class AutoSchema(SwaggerAutoSchema):
     @property
     def model(self):
-        if hasattr(self.view, "queryset") and self.view.queryset is not None:
-            return self.view.queryset.model
-
         if hasattr(self.view, "get_queryset"):
             qs = self.view.get_queryset()
             return qs.model
@@ -247,23 +235,10 @@ class AutoSchema(SwaggerAutoSchema):
             )
 
         filters = {}
-        for parameter in filter_fields:
-            help_text = parameter.description
-            # we can't get the verbose_label back from the enum, so the inspector
-            # in vng_api_common.inspectors.fields leaves a filter field reference behind
-            _filter_field = getattr(parameter, "_filter_field", None)
-            choices = getattr(_filter_field, "extra", {}).get("choices", [])
-            if choices:
-                FieldClass = serializers.ChoiceField
-                extra = {"choices": choices}
-                value_display_mapping = add_choice_values_help_text(choices)
-                help_text += f"\n\n{value_display_mapping}"
-            else:
-                FieldClass = TYPE_TO_FIELDMAPPING[parameter.type]
-                extra = {}
-
-            filters[parameter.name] = FieldClass(
-                help_text=help_text, required=parameter.required, **extra
+        for filter_field in filter_fields:
+            FieldClass = TYPE_TO_FIELDMAPPING[filter_field.type]
+            filters[filter_field.name] = FieldClass(
+                help_text=filter_field.description, required=filter_field.required
             )
 
         SearchSerializer = type(Base.__name__, (Base,), filters)
@@ -277,36 +252,6 @@ class AutoSchema(SwaggerAutoSchema):
             schema = self.get_paginated_response(schema) or schema
         return OrderedDict({str(response_status): schema})
 
-    def register_error_responses(self):
-        ref_responses = self.components.with_scope("responses")
-
-        if not ref_responses.keys():
-            # general errors
-            general_classes = list(chain(*DEFAULT_ACTION_ERRORS.values()))
-            # add geo and validation errors
-            exception_classes = general_classes + [
-                PreconditionFailed,
-                exceptions.ValidationError,
-            ]
-            status_codes = sorted({e.status_code for e in exception_classes})
-
-            fout_schema = self.serializer_to_schema(FoutSerializer())
-            validation_fout_schema = self.serializer_to_schema(
-                ValidatieFoutSerializer()
-            )
-            for status_code in status_codes:
-                schema = (
-                    validation_fout_schema
-                    if status_code == exceptions.ValidationError.status_code
-                    else fout_schema
-                )
-                response = openapi.Response(
-                    description=HTTP_STATUS_CODE_TITLES.get(status_code, ""),
-                    schema=schema,
-                )
-                self.set_response_headers(str(status_code), response)
-                ref_responses.set(str(status_code), response)
-
     def _get_error_responses(self) -> OrderedDict:
         """
         Add the appropriate possible error responses to the schema.
@@ -314,38 +259,51 @@ class AutoSchema(SwaggerAutoSchema):
         E.g. - we know that HTTP 400 on a POST/PATCH/PUT leads to validation
         errors, 403 to Permission Denied etc.
         """
+        # only supports viewsets
+        if not hasattr(self.view, "action"):
+            return OrderedDict()
 
-        self.register_error_responses()
-
+        responses = {}
         action = self.view.action
+
         if (
             action not in DEFAULT_ACTION_ERRORS and self._is_search_view
         ):  # similar to a CREATE
             action = "create"
 
-        # general errors
-        general_klasses = DEFAULT_ACTION_ERRORS.get(action)
-        if general_klasses is None:
+        exception_klasses = DEFAULT_ACTION_ERRORS.get(action)
+        if exception_klasses is None:
             logger.debug("Unknown action %s, no default error responses added")
-            return OrderedDict()
+            return responses
+
+        fout_schema = self.serializer_to_schema(FoutSerializer())
+        for exception_klass in exception_klasses:
+            status_code = exception_klass.status_code
+            responses[status_code] = fout_schema
 
-        exception_klasses = general_klasses[:]
-        # add geo and validation errors
         has_validation_errors = self.get_filter_parameters() or any(
             issubclass(klass, exceptions.ValidationError) for klass in exception_klasses
         )
         if has_validation_errors:
-            exception_klasses.append(exceptions.ValidationError)
+            schema = self.serializer_to_schema(ValidatieFoutSerializer())
+            responses[exceptions.ValidationError.status_code] = schema
 
         if isinstance(self.view, GeoMixin):
-            exception_klasses.append(PreconditionFailed)
+            status_code = PreconditionFailed.status_code
+            responses[status_code] = fout_schema
 
-        status_codes = sorted({e.status_code for e in exception_klasses})
+        # sort by status code
 
         return OrderedDict(
             [
-                (status_code, ResponseRef(self.components, str(status_code)))
-                for status_code in status_codes
+                (
+                    status_code,
+                    openapi.Response(
+                        description=HTTP_STATUS_CODE_TITLES.get(status_code, ""),
+                        schema=schema,
+                    ),
+                )
+                for status_code, schema in sorted(responses.items())
             ]
         )
 
@@ -359,17 +317,23 @@ class AutoSchema(SwaggerAutoSchema):
 
         # inject any headers
         _responses = OrderedDict()
+        custom_headers = OrderedDict()
         for status_, schema in responses.items():
-            custom_headers = (
-                self.probe_inspectors(
-                    self.field_inspectors,
-                    "get_response_headers",
-                    serializer,
-                    {"field_inspectors": self.field_inspectors},
-                    status=status_,
+            if serializer is not None:
+                custom_headers = (
+                    self.probe_inspectors(
+                        self.field_inspectors,
+                        "get_response_headers",
+                        serializer,
+                        {"field_inspectors": self.field_inspectors},
+                        status=status_,
+                    )
+                    or OrderedDict()
                 )
-                or None
-            )
+
+            # add the cache headers, if applicable
+            for header, header_schema in get_cache_headers(self.view).items():
+                custom_headers[header] = header_schema
 
             assert isinstance(schema, openapi.Schema.OR_REF) or schema == ""
             response = openapi.Response(
@@ -384,56 +348,61 @@ class AutoSchema(SwaggerAutoSchema):
 
         return _responses
 
-    @staticmethod
-    def set_response_headers(
-        status_code: str, response: Union[openapi.Response, ResponseRef]
-    ):
-        if not isinstance(response, openapi.Response):
-            return
-
-        response.setdefault("headers", OrderedDict())
-        response["headers"][VERSION_HEADER] = version_header
-
-        if status_code == "201":
-            response["headers"]["Location"] = location_header
-
     def get_response_schemas(self, response_serializers):
-        # parent class doesn't support responses as ref objects,
-        # so we temporary remove them
-        ref_responses = OrderedDict()
-        for status_code, serializer in response_serializers.copy().items():
-            if isinstance(serializer, ResponseRef):
-                ref_responses[str(status_code)] = response_serializers.pop(status_code)
-
         responses = super().get_response_schemas(response_serializers)
 
-        # and add them again
-        responses.update(ref_responses)
-        responses = OrderedDict(sorted(responses.items()))
-
         # add the Api-Version headers
         for status_code, response in responses.items():
-            self.set_response_headers(status_code, response)
+            response.setdefault("headers", OrderedDict())
+            response["headers"][VERSION_HEADER] = version_header
+
+            if status_code == "201":
+                response["headers"]["Location"] = location_header
 
         return responses
 
+    def get_request_content_type_header(self) -> Optional[openapi.Parameter]:
+        if self.method not in ["POST", "PUT", "PATCH"]:
+            return None
+
+        consumes = get_consumes(self.get_parser_classes())
+        return openapi.Parameter(
+            name="Content-Type",
+            in_=openapi.IN_HEADER,
+            type=openapi.TYPE_STRING,
+            required=True,
+            enum=consumes,
+            description=_("Content type of the request body."),
+        )
+
     def add_manual_parameters(self, parameters):
         base = super().add_manual_parameters(parameters)
+
+        content_type = self.get_request_content_type_header()
+        if content_type is not None:
+            base = [content_type] + base
+
         if self._is_search_view:
             serializer = self.get_request_serializer()
         else:
             serializer = self.get_request_serializer() or self.get_view_serializer()
-        extra = (
-            self.probe_inspectors(
-                self.field_inspectors,
-                "get_request_header_parameters",
-                serializer,
-                {"field_inspectors": self.field_inspectors},
+
+        extra = []
+        if serializer is not None:
+            extra = (
+                self.probe_inspectors(
+                    self.field_inspectors,
+                    "get_request_header_parameters",
+                    serializer,
+                    {"field_inspectors": self.field_inspectors},
+                )
+                or []
             )
-            or []
-        )
         result = base + extra
 
+        if has_cache_header(self.view):
+            result += CACHE_REQUEST_HEADERS
+
         if _view_supports_audittrail(self.view):
             result += AUDIT_REQUEST_HEADERS
 
@@ -464,7 +433,7 @@ class AutoSchema(SwaggerAutoSchema):
 
         required_scopes = []
         for perm in scope_permissions:
-            scopes = get_required_scopes(self.view)
+            scopes = get_required_scopes(self.request, self.view)
             if scopes is None:
                 continue
             required_scopes.append(scopes)
@@ -477,6 +446,27 @@ class AutoSchema(SwaggerAutoSchema):
         # operation level security
         return [{settings.SECURITY_DEFINITION_NAME: scopes}]
 
+    # all of these break if you accept method HEAD because the view.action is None
+    def is_list_view(self) -> bool:
+        if self.method == "HEAD":
+            return False
+        return super().is_list_view()
+
+    def get_summary_and_description(self) -> Tuple[str, str]:
+        if self.method != "HEAD":
+            return super().get_summary_and_description()
+
+        default_description = _(
+            "De headers voor een specifiek(e) {model_name} opvragen"
+        ).format(model_name=self.model._meta.model_name.upper())
+        default_summary = _(
+            "Vraag de headers op die je bij een GET request zou krijgen."
+        )
+
+        description = self.overrides.get("operation_description", default_description)
+        summary = self.overrides.get("operation_summary", default_summary)
+        return description, summary
+
     # patch around drf-yasg not taking overrides into account
     # TODO: contribute back in PR
     def get_produces(self) -> list:
