@@ -1,12 +1,12 @@
 # https://pyjwt.readthedocs.io/en/latest/usage.html#reading-headers-without-validation
 # -> we can put the organization/service in the headers itself
 import logging
-from typing import List, Optional, Union
+from typing import Any, Dict, List, Optional
 
 from django.conf import settings
 from django.db import models, transaction
 from django.db.models import QuerySet
-from django.utils.translation import gettext as _
+from django.utils.translation import ugettext as _
 
 import jwt
 from djangorestframework_camel_case.util import underscoreize
@@ -28,7 +28,7 @@ class JWTAuth:
         self.encoded = encoded
 
     @property
-    def applicaties(self) -> Union[list, None]:
+    def applicaties(self) -> Optional[list]:
         if self.client_id is None:
             return []
 
@@ -88,7 +88,7 @@ class JWTAuth:
         return applicaties
 
     @property
-    def payload(self):
+    def payload(self) -> Optional[Dict[str, Any]]:
         if self.encoded is None:
             return None
 
@@ -97,12 +97,7 @@ class JWTAuth:
 
             # jwt check
             try:
-                payload = jwt.decode(
-                    self.encoded,
-                    algorithms=["HS256"],
-                    options={"verify_signature": False},
-                    leeway=settings.JWT_LEEWAY,
-                )
+                payload = jwt.decode(self.encoded, verify=False)
             except jwt.DecodeError:
                 logger.info("Invalid JWT encountered")
                 raise PermissionDenied(
@@ -116,35 +111,16 @@ class JWTAuth:
             try:
                 client_id = payload["client_id"]
             except KeyError:
-                try:
-                    header = jwt.get_unverified_header(self.encoded)
-                except jwt.DecodeError:
-                    logger.info("Invalid JWT encountered")
-                    raise PermissionDenied(
-                        _(
-                            "JWT could not be decoded. Possibly you made a copy-paste mistake."
-                        ),
-                        code="jwt-decode-error",
-                    )
-                else:
-                    try:
-                        client_id = header["client_identifier"]
-                    except KeyError:
-                        raise PermissionDenied(
-                            "Client identifier is niet aanwezig in JWT",
-                            code="missing-client-identifier",
-                        )
-                    else:
-                        logger.warning(
-                            _(
-                                "The support of authorization old format will be terminated soon. "
-                                "Please use a new format with the separate Authorization Component"
-                            )
-                        )
+                raise PermissionDenied(
+                    "Client identifier is niet aanwezig in JWT",
+                    code="missing-client-identifier",
+                )
 
-            # find client_id in DB and retrieve it's secret
+            # find client_id in DB and retrieve its secret
             try:
-                jwt_secret = JWTSecret.objects.get(identifier=client_id)
+                jwt_secret = JWTSecret.objects.exclude(secret="").get(
+                    identifier=client_id
+                )
             except JWTSecret.DoesNotExist:
                 raise PermissionDenied(
                     "Client identifier bestaat niet", code="invalid-client-identifier"
@@ -154,30 +130,21 @@ class JWTAuth:
 
             # check signature of the token
             try:
-                payload = jwt.decode(
-                    self.encoded,
-                    key,
-                    algorithms="HS256",
-                    leeway=settings.JWT_LEEWAY,
-                )
+                payload = jwt.decode(self.encoded, key, algorithms="HS256")
             except jwt.InvalidSignatureError:
                 logger.exception("Invalid signature - possible payload tampering?")
                 raise PermissionDenied(
                     "Client credentials zijn niet geldig", code="invalid-jwt-signature"
                 )
 
-            if "client_id" not in payload:
-                payload["client_id"] = client_id
-
             self._payload = payload
 
         return self._payload
 
     @property
-    def client_id(self):
+    def client_id(self) -> str:
         if not self.payload:
             return None
-
         return self.payload["client_id"]
 
     def filter_vertrouwelijkheidaanduiding(self, base: QuerySet, value) -> QuerySet:
