@@ -1,18 +1,19 @@
 import logging
 import re
 import uuid
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import Union
 
 from django.apps import apps
 from django.conf import settings
 from django.db import models
 from django.http import HttpRequest
-from django.urls import Resolver404, ResolverMatch, get_resolver, get_script_prefix
+from django.urls import Resolver404, get_resolver
+from django.utils.encoding import smart_text
+from django.utils.module_loading import import_string
 
+from rest_framework.utils import formatting
 from zds_client.client import ClientError
 
-from .client import get_client
-
 try:
     from djangorestframework_camel_case.util import (
         underscore_to_camel as _underscore_to_camel,
@@ -22,9 +23,6 @@ except ImportError:
         underscoreToCamel as _underscore_to_camel,
     )
 
-if TYPE_CHECKING:
-    from rest_framework.viewsets import ViewSet
-
 
 logger = logging.getLogger(__name__)
 
@@ -54,22 +52,18 @@ class NotAViewSet(Exception):
     pass
 
 
-def resolve_path(path: str, resolver=None, script_prefix=None) -> ResolverMatch:
-    resolver = resolver or get_resolver()
-    prefix = script_prefix or get_script_prefix()
-    path = path.replace(prefix, "/", 1)
-    try:
-        return resolver.resolve(path)
-    except Resolver404 as exc:
-        raise models.ObjectDoesNotExist("URL did not resolve") from exc
-
-
-def get_viewset_for_path(path: str, method="GET") -> "ViewSet":
+def get_viewset_for_path(path: str, method="GET") -> "rest_framework.viewsets.ViewSet":
     """
     Look up which viewset matches a path.
     """
     # NOTE: this doesn't support setting a different urlconf on the request
-    callback, callback_args, callback_kwargs = resolve_path(path)
+    resolver = get_resolver()
+
+    try:
+        resolver_match = resolver.resolve(path)
+    except Resolver404 as exc:
+        raise models.ObjectDoesNotExist("URL did not resolve") from exc
+    callback, callback_args, callback_kwargs = resolver_match
 
     if not hasattr(callback, "cls"):
         raise NotAViewSet(f"Callback for {path} does not look like a viewset")
@@ -102,61 +96,6 @@ def get_resource_for_path(path: str) -> models.Model:
     return viewset.get_queryset().get(**filter_kwargs)
 
 
-def get_resources_for_paths(paths: List[str]) -> Optional[models.QuerySet]:
-    """
-    Retrieve API instances belonging to a list of (detail) paths.
-
-    This is the bulk version of :func:`vng_api_common.utils.get_resource_for_path`,
-    which doesn't scale well when a lot of paths are involved. This replaces many
-    queries with a single bulk query.
-
-    .. warning::
-
-        This means that all the resource paths must point to the same resource, as the
-        viewset will only be fetched once from the first item and used to retrieve
-        all the resources.
-
-        This function compares the number of resolved instances vs the number of input
-        paths, and if that is not equal, there's something off and a :class:`RuntimeError`
-        is raised.
-    """
-    if not paths:
-        return None
-
-    # NOTE: this doesn't support setting a different urlconf on the request
-    resolver = get_resolver()
-    prefix = get_script_prefix()
-    lookup_kwarg_values = []
-
-    for path in paths:
-        callback, callback_args, callback_kwargs = resolve_path(
-            path,
-            resolver=resolver,
-            script_prefix=prefix,
-        )
-
-        if not hasattr(callback, "cls"):
-            raise NotAViewSet(f"Callback for {path} does not look like a viewset")
-
-        viewset_cls = callback.cls
-        lookup_url_kwarg = viewset_cls.lookup_url_kwarg or viewset_cls.lookup_field
-        lookup_kwarg_values.append(callback_kwargs[lookup_url_kwarg])
-
-    queryset = viewset_cls().get_queryset()
-    # drop any joins or prefetch_related to speed things up even more
-    queryset = queryset.select_related(None).prefetch_related(None)
-
-    filtered_queryset = queryset.filter(
-        **{f"{viewset_cls.lookup_field}__in": lookup_kwarg_values}
-    )
-    if not len(filtered_queryset) == len(paths):
-        raise RuntimeError(
-            f"Some paths could not be resolved with viewset {viewset_cls} - are you sure "
-            "that all paths point to the same resource?"
-        )
-    return filtered_queryset
-
-
 def underscore_to_camel(input_: Union[str, int]) -> str:
     """
     Convert a string from under_score to camelCase.
@@ -185,8 +124,11 @@ def get_uuid_from_path(path: str) -> str:
 def request_object_attribute(
     url: str, attribute: str, resource: Union[str, None] = None
 ) -> str:
-    client = get_client(url)
+    from .models import APICredential
 
+    Client = import_string(settings.ZDS_CLIENT_CLASS)
+    client = Client.from_url(url)
+    client.auth = APICredential.get_auth(url)
     try:
         result = client.retrieve(resource, url=url)[attribute]
     except (ClientError, KeyError) as exc:
@@ -255,15 +197,7 @@ def get_view_summary(view_cls):
         if "\n\n" in summary:
             summary = summary.rsplit("\n\n", 1)[0].strip().replace("\r", "")
             return formatting.dedent(smart_text(summary))
-    except (AttributeError, IndexError):
+    except (AttributeError, IndexError) as e:
         pass
 
     return ""
-
-
-def get_field_attribute(
-    model_string: str, field_name: str, attr_name: str
-) -> Optional[str]:
-    ModelClass = apps.get_model(model_string, require_ready=False)
-    field = ModelClass._meta.get_field(field_name)
-    return getattr(field, attr_name, None)
